@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "triggerconfigwidget.h"
 #include "triggerlistview.h"
@@ -25,7 +13,7 @@
 
 Palapeli::TriggerConfigWidget::TriggerConfigWidget(QWidget* parent)
 	: QTabWidget(parent)
-	, m_interactors(Palapeli::TriggerMapper::createInteractors(0)) //these interactors are just for reading metadata
+	, m_interactors(Palapeli::TriggerMapper::createInteractors(nullptr)) //these interactors are just for reading metadata
 	, m_mouseView(new Palapeli::TriggerListView(m_interactors, Palapeli::MouseInteractor, this))
 	, m_wheelView(new Palapeli::TriggerListView(m_interactors, Palapeli::WheelInteractor, this))
 {
@@ -69,7 +57,7 @@ void Palapeli::TriggerConfigWidget::updateWidgets()
 	const QMap<QByteArray, Palapeli::Trigger> associations = Palapeli::TriggerMapper::instance()->associations();
 	m_mouseView->setAssociations(associations);
 	m_wheelView->setAssociations(associations);
-	emit associationsChanged();
+	Q_EMIT associationsChanged();
 }
 
 void Palapeli::TriggerConfigWidget::updateWidgetsDefault()
@@ -77,7 +65,7 @@ void Palapeli::TriggerConfigWidget::updateWidgetsDefault()
 	const QMap<QByteArray, Palapeli::Trigger> associations = Palapeli::TriggerMapper::defaultAssociations();
 	m_mouseView->setAssociations(associations);
 	m_wheelView->setAssociations(associations);
-	emit associationsChanged();
+	Q_EMIT associationsChanged();
 }
 
 
