@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2011 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PALAPELI_COMPONENTS_H
 #define PALAPELI_COMPONENTS_H
@@ -24,11 +12,12 @@
 
 class KConfigGroup;
 class QTemporaryDir;
+class QMutex;
 
 #define COMPONENT_SUBCLASS(mytype) \
 	public: \
 	enum { ComponentType = mytype }; \
-	Type type() const Q_DECL_OVERRIDE { return mytype; }
+	Type type() const override { return mytype; }
 
 namespace Palapeli
 {
@@ -58,7 +47,7 @@ namespace Palapeli
 			explicit CreationContextComponent(const Palapeli::PuzzleCreationContext& creationContext) : creationContext(creationContext) {}
 
 			Palapeli::PuzzleCreationContext creationContext;
-			Palapeli::PuzzleComponent* cast(Type type) const Q_DECL_OVERRIDE;
+			Palapeli::PuzzleComponent* cast(Type type) const override;
 	};
 
 	///This component copies the data (i.e. everything in puzzlestructs.h) from
@@ -69,7 +58,7 @@ namespace Palapeli
 		public:
 			explicit CopyComponent(Palapeli::Puzzle* puzzle);
 
-			Palapeli::PuzzleComponent* cast(Type type) const Q_DECL_OVERRIDE;
+			Palapeli::PuzzleComponent* cast(Type type) const override;
 		private:
 			Palapeli::Puzzle* m_puzzle;
 	};
@@ -81,10 +70,10 @@ namespace Palapeli
 		public:
 			DirectoryStorageComponent();
 			static Palapeli::DirectoryStorageComponent* fromData(Palapeli::Puzzle* puzzle);
-			virtual ~DirectoryStorageComponent();
+			~DirectoryStorageComponent() override;
 
 			QString directory() const;
-			Palapeli::PuzzleComponent* cast(Type type) const Q_DECL_OVERRIDE;
+			Palapeli::PuzzleComponent* cast(Type type) const override;
 		private:
 			QTemporaryDir* m_dir;
 	};
@@ -97,7 +86,7 @@ namespace Palapeli
 			ArchiveStorageComponent();
 			static Palapeli::ArchiveStorageComponent* fromData(Palapeli::Puzzle* puzzle);
 
-			Palapeli::PuzzleComponent* cast(Type type) const Q_DECL_OVERRIDE;
+			Palapeli::PuzzleComponent* cast(Type type) const override;
 	};
 
 	///This is a valid mainComponent.
@@ -106,13 +95,12 @@ namespace Palapeli
 		COMPONENT_SUBCLASS(CollectionStorage)
 		public:
 			///Takes ownership of @a group.
-			CollectionStorageComponent(KConfigGroup* group, QMutex *groupMutex);
-			virtual ~CollectionStorageComponent();
+			CollectionStorageComponent(KConfigGroup* group);
+			~CollectionStorageComponent() override;
 
-			Palapeli::PuzzleComponent* cast(Type type) const Q_DECL_OVERRIDE;
+			Palapeli::PuzzleComponent* cast(Type type) const override;
 		private:
 			KConfigGroup* m_group;
-			QMutex *m_groupMutex;
 	};
 
 	///This is used by the collection if, instead of an actual puzzle archive,
@@ -124,7 +112,7 @@ namespace Palapeli
 		public:
 			explicit RetailStorageComponent(const QString& desktopFile);
 
-			Palapeli::PuzzleComponent* cast(Type type) const Q_DECL_OVERRIDE;
+			Palapeli::PuzzleComponent* cast(Type type) const override;
 		private:
 			QString m_desktopFile;
 	};
